Changelog
=========


1.1.0 (2017-02-23)
------------------

- Upgrade to last storage, permissions and cache backends features. (#7)


1.0.1 (2016-08-18)
------------------

**Bug fixes**

- Fix compability with Kinto 4.0 about unique fields (Kinto/kinto#763)


1.0.0 (2016-08-11)
------------------

- Move the kinto redis backends to an external repository.
